#[non_exhaustive]
pub enum Request<'a> { Destroy, SetSize { width: u32, height: u32, }, SetAnchor { anchor: WEnum<Anchor>, }, SetGravity { gravity: WEnum<Gravity>, }, SetConstraintAdjustment { constraint_adjustment: WEnum<ConstraintAdjustment>, }, SetOffset { x: i32, y: i32, }, SetReactive, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy the input_popup_positioner object

Notify the compositor that the positioner will no longer be used.

This is a destructor, once sent this object cannot be used any longer.



SetSize

set the size of the to-be positioned rectangle

Set the size of the surface that is to be positioned with the positioner object. The size is in surface-local coordinates and corresponds to the window geometry. See xdg_surface.set_window_geometry.

If any dimension is set to zero, the invalid_input error is raised.

Fields

width: u32

width of positioned rectangle

height: u32

height of positioned rectangle



SetAnchor

set anchor rectangle anchor

Defines the anchor point for the anchor rectangle. The specified anchor is used to derive an anchor point that the popup surface will be positioned relative to. If a corner anchor is set (e.g. ‘top_left’ or ‘bottom_right’), the anchor point will be at the specified corner; otherwise, the derived anchor point will be centered on the specified edge, or in the center of the anchor rectangle if no edge is specified.

Fields

anchor: WEnum<Anchor>

anchor



SetGravity

set surface gravity

Defines in what direction the surface should be positioned, relative to the anchor point of the anchor rectangle. If a corner gravity is specified (e.g. ‘bottom_right’ or ‘top_left’), then the surface will be placed towards the specified gravity; otherwise, the child surface will be centered over the anchor point on any axis that had no gravity specified. If the gravity is not in the ‘gravity’ enum, an invalid_input error is raised.

Fields

gravity: WEnum<Gravity>

gravity direction



SetConstraintAdjustment

set the adjustment to be done when constrained

Specify how the popup should be positioned if the originally intended position caused the surface to be constrained, meaning at least partially outside positioning boundaries set by the compositor. The adjustment is set by constructing a bitmask describing the adjustment to be made when the surface is constrained on that axis.

If no bit for one axis is set, the compositor will assume that the child surface should not change its position on that axis when constrained.

If more than one bit for one axis is set, the order of how adjustments are applied is specified in the corresponding adjustment descriptions.

The default adjustment is none.

Fields

constraint_adjustment: WEnum<ConstraintAdjustment>

bit mask of constraint adjustments



SetOffset

set surface position offset

Specify the surface position offset relative to the position of the anchor on the anchor rectangle and the anchor on the surface. For example if the anchor of the anchor rectangle is at (x, y), the surface has the gravity bottom|right, and the offset is (ox, oy), the calculated surface position will be (x + ox, y + oy). The offset position of the surface is the one used for constraint testing. See set_constraint_adjustment.

An example use case is placing a popup menu on top of a user interface element, while aligning the user interface element of the parent surface with some user interface element placed somewhere in the popup surface.

Fields

x: i32

surface position x offset

y: i32

surface position y offset



SetReactive

continuously reconstrain the surface

When set reactive, the surface is reconstrained if the conditions used for constraining changed, e.g. the window containing the text input moved.

Whenever the conditions change and the popup gets reconstrained, a configure sequence is sent with updated geometry.

Implementations



impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message